Documentation
¶
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func NewIngress(namespace, name string, obj v1beta1.Ingress) *v1beta1.Ingress
- func Resource(resource string) schema.GroupResource
- type Client
- type IngressChangeHandlerFunc
- type IngressController
- type IngressHandlerFunc
- type IngressInterface
- type IngressLifecycle
- type IngressList
- type IngressLister
- type IngressesGetter
- type Interface
Constants ¶
const ( GroupName = "extensions" Version = "v1beta1" )
Variables ¶
var ( IngressGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Ingress", } IngressResource = metav1.APIResource{ Name: "ingresses", SingularName: "ingress", Namespaced: true, Kind: IngressGroupVersionKind.Kind, } IngressGroupVersionResource = schema.GroupVersionResource{ Group: GroupName, Version: Version, Resource: "ingresses", } )
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: Version}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Client ¶
func (*Client) Ingresses ¶
func (c *Client) Ingresses(namespace string) IngressInterface
func (*Client) RESTClient ¶
type IngressController ¶
type IngressController interface {
Generic() controller.GenericController
Informer() cache.SharedIndexInformer
Lister() IngressLister
AddHandler(ctx context.Context, name string, handler IngressHandlerFunc)
AddFeatureHandler(ctx context.Context, enabled func() bool, name string, sync IngressHandlerFunc)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, handler IngressHandlerFunc)
AddClusterScopedFeatureHandler(ctx context.Context, enabled func() bool, name, clusterName string, handler IngressHandlerFunc)
Enqueue(namespace, name string)
EnqueueAfter(namespace, name string, after time.Duration)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type IngressHandlerFunc ¶
func NewIngressLifecycleAdapter ¶
func NewIngressLifecycleAdapter(name string, clusterScoped bool, client IngressInterface, l IngressLifecycle) IngressHandlerFunc
type IngressInterface ¶
type IngressInterface interface {
ObjectClient() *objectclient.ObjectClient
Create(*v1beta1.Ingress) (*v1beta1.Ingress, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1beta1.Ingress, error)
Get(name string, opts metav1.GetOptions) (*v1beta1.Ingress, error)
Update(*v1beta1.Ingress) (*v1beta1.Ingress, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*IngressList, error)
ListNamespaced(namespace string, opts metav1.ListOptions) (*IngressList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() IngressController
AddHandler(ctx context.Context, name string, sync IngressHandlerFunc)
AddFeatureHandler(ctx context.Context, enabled func() bool, name string, sync IngressHandlerFunc)
AddLifecycle(ctx context.Context, name string, lifecycle IngressLifecycle)
AddFeatureLifecycle(ctx context.Context, enabled func() bool, name string, lifecycle IngressLifecycle)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, sync IngressHandlerFunc)
AddClusterScopedFeatureHandler(ctx context.Context, enabled func() bool, name, clusterName string, sync IngressHandlerFunc)
AddClusterScopedLifecycle(ctx context.Context, name, clusterName string, lifecycle IngressLifecycle)
AddClusterScopedFeatureLifecycle(ctx context.Context, enabled func() bool, name, clusterName string, lifecycle IngressLifecycle)
}
type IngressLifecycle ¶
type IngressList ¶
type IngressList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1beta1.Ingress `json:"items"`
}
func (*IngressList) DeepCopy ¶
func (in *IngressList) DeepCopy() *IngressList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IngressList.
func (*IngressList) DeepCopyInto ¶
func (in *IngressList) DeepCopyInto(out *IngressList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IngressList) DeepCopyObject ¶
func (in *IngressList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type IngressLister ¶
type IngressesGetter ¶
type IngressesGetter interface {
Ingresses(namespace string) IngressInterface
}
type Interface ¶
type Interface interface {
RESTClient() rest.Interface
controller.Starter
IngressesGetter
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.